@@ -139,7 +139,36 @@ x,y = userImages.size
             return userImages, -119           
 '''
 def centryImage(userImages, teample = 1):
-    if teample == 1:
+    if teample == 6:
+        x,y = userImages.size
+        if max(x, y) / min(x, y) < 1.1:
+            baseheight = 1615
+            hpercent = (baseheight / float (y)) 
+            wsize = int ((float (x) * float (hpercent)))
+            userImages = userImages.resize ((wsize, baseheight), Image.LANCZOS)
+            return userImages, -235
+            # квадратное 
+        elif x > y:
+            baseheight = 1615
+            hpercent = (baseheight / float (y)) 
+            wsize = int ((float (x) * float (hpercent)))
+            userImages = userImages.resize ((wsize, baseheight), Image.LANCZOS)
+            return userImages, int(515 -userImages.size[0]/2)
+        else:
+            basewidth = 1066
+            wpercent = (basewidth / float(userImages.size[0]))
+            hsize = int((float(userImages.size[1]) * float(wpercent)))
+            if hsize < 1615:
+                baseheight = 1615
+                hpercent = (baseheight / float (y)) 
+                wsize = int ((float (x) * float (hpercent)))
+                userImages = userImages.resize ((wsize, baseheight), Image.LANCZOS)
+                return userImages, int(515 -userImages.size[0]/2)
+            userImages = userImages.resize((basewidth, hsize), Image.LANCZOS)
+
+            return userImages, 0
+        
+    elif teample == 1:
         x,y = userImages.size
         if max(x, y) / min(x, y) < 1.1:
             baseheight = 787
@@ -159,6 +188,12 @@ def centryImage(userImages, teample = 1):
             basewidth = 575
             wpercent = (basewidth / float(userImages.size[0]))
             hsize = int((float(userImages.size[1]) * float(wpercent)))
+            if hsize < 787:
+                baseheight = 787
+                hpercent = (baseheight / float (y)) 
+                wsize = int ((float (x) * float (hpercent)))
+                userImages = userImages.resize ((wsize, baseheight), Image.LANCZOS)
+                return userImages, int(271 -userImages.size[0]/2)
             userImages = userImages.resize((basewidth, hsize), Image.LANCZOS)
             return userImages, 0
             # вертикальное
@@ -174,17 +209,18 @@ def centryImage(userImages, teample = 1):
             # квадратное 
             pass
         elif x > y:
+
             baseheight = 1047
             hpercent = (baseheight / float (y)) 
             wsize = int ((float (x) * float (hpercent)))
             userImages = userImages.resize ((wsize, baseheight), Image.LANCZOS)
             return userImages, int(972 -userImages.size[0]/2), 1
         else:
-            baseheight = 1239
-            hpercent = (baseheight / float (y)) 
-            wsize = int ((float (x) * float (hpercent)))
-            userImages = userImages.resize ((wsize, baseheight), Image.LANCZOS)
-            return userImages, 659, 2
+            basewidth = 1029
+            wpercent = (basewidth / float(userImages.size[0]))
+            hsize = int((float(userImages.size[1]) * float(wpercent)))
+            userImages = userImages.resize((basewidth, hsize), Image.LANCZOS)
+            return userImages, 509,2
             # вертикальное
     elif teample == 4:
         x,y = userImages.size
@@ -206,6 +242,12 @@ def centryImage(userImages, teample = 1):
             basewidth = 388
             wpercent = (basewidth / float(userImages.size[0]))
             hsize = int((float(userImages.size[1]) * float(wpercent)))
+            if hsize < 618:
+                baseheight = 621
+                hpercent = (baseheight / float (y)) 
+                wsize = int ((float (x) * float (hpercent)))
+                userImages = userImages.resize ((wsize, baseheight), Image.LANCZOS)
+                return userImages, int(194 -userImages.size[0]/2)
             userImages = userImages.resize((basewidth, hsize), Image.LANCZOS)
             return userImages, 0
             # вертикальное
@@ -229,6 +271,12 @@ def centryImage(userImages, teample = 1):
             wpercent = (basewidth / float(userImages.size[0]))
             hsize = int((float(userImages.size[1]) * float(wpercent)))
             userImages = userImages.resize((basewidth, hsize), Image.LANCZOS)
+            if hsize < 802:
+                baseheight = 802
+                hpercent = (baseheight / float (y)) 
+                wsize = int ((float (x) * float (hpercent)))
+                userImages = userImages.resize ((wsize, baseheight), Image.LANCZOS)
+                return userImages, (int(300  -userImages.size[0]/2),0), 2
             return userImages, (0,0), 2
 
 
@@ -352,12 +400,10 @@ def userImage(img,element = None, adaptation = False):
     if adaptation:
         grandient = userAdaptGrandient(userImagess.convert("RGB").copy())
         Effect = openFile.UserEffectTeampleOne.copy().convert('RGBA')
-        grandient.show()
         grandient = ImageChops.soft_light(grandient,Effect)
         
         Effect.alpha_composite(userImagess,(pozitionX,0))
         im = Image.composite(Effect, grandient, openFile.MaskaUserBg2TeampleOne.convert("L"))
-        im.show()
         return im
     else:
         try:
@@ -474,7 +520,8 @@ def elementIconPanel(element):
     else:
         return Image.open(f'{path}/teapmleTwo/charter_element/PYRO.png')
 
-def getIconAdd(x, icon = False, size = None):
+def getIconAdd(x, icon = False, size = None, element = False):
+    elements = False
     if not icon:
         if not x in IconAddTrue:
             return False
@@ -493,7 +540,10 @@ def getIconAdd(x, icon = False, size = None):
     elif x == "FIGHT_PROP_CHARGE_EFFICIENCY":
         icons = Image.open(f'{path}/icon/CHARGE_EFFICIENCY.png')
     elif x == "FIGHT_PROP_ELEC_ADD_HURT":
-        icons = Image.open(f'{path}/icon/ELECTRO.png')
+        if not element:
+            icons = Image.open(f'{path}/icon/ELECTRO.png')
+        else:
+            icons = Image.open(f'{path}/icon/ELECTRO_UP.png').resize(())
     elif x == "FIGHT_PROP_DEFENSE_PERCENT":
         icons = Image.open(f'{path}/icon/DEFENSE_PERCENT.png')
     elif x == "FIGHT_PROP_ATTACK_PERCENT":
@@ -501,17 +551,35 @@ def getIconAdd(x, icon = False, size = None):
     elif x == "FIGHT_PROP_HP_PERCENT":
         icons = Image.open(f'{path}/icon/HP_PERCENT.png')
     elif x == "FIGHT_PROP_WATER_ADD_HURT":
-        icons = Image.open(f'{path}/icon/HYDRO.png')
+        if not element:
+            icons = Image.open(f'{path}/icon/HYDRO.png')
+        else:
+            icons = Image.open(f'{path}/icon/HYDRO_UP.png')
     elif x == "FIGHT_PROP_WIND_ADD_HURT":
-        icons = Image.open(f'{path}/icon/ANEMO.png')
+        if not element:
+            icons = Image.open(f'{path}/icon/ANEMO.png')
+        else:
+            icons = Image.open(f'{path}/icon/ANEMO_UP.png')
     elif x == "FIGHT_PROP_ICE_ADD_HURT":
-        icons = Image.open(f'{path}/icon/CRYO.png')
+        if not element:
+            icons = Image.open(f'{path}/icon/CRYO.png')
+        else:
+            icons = Image.open(f'{path}/icon/CRYO_UP.png')
     elif x == "FIGHT_PROP_ROCK_ADD_HURT":
-        icons = Image.open(f'{path}/icon/GEO.png')
+        if not element:
+            icons = Image.open(f'{path}/icon/GEO.png')
+        else:
+            icons = Image.open(f'{path}/icon/GEO_UP.png')
     elif x == "FIGHT_PROP_FIRE_ADD_HURT":
-        icons = Image.open(f'{path}/icon/PYRO.png')
+        if not element:
+            icons = Image.open(f'{path}/icon/PYRO.png')
+        else:
+            icons = Image.open(f'{path}/icon/PYRO_UP.png')
     elif x == "FIGHT_PROP_GRASS_ADD_HURT":
-        icons = Image.open(f'{path}/icon/DENDRO.png')
+        if not element:
+            icons = Image.open(f'{path}/icon/DENDRO.png')
+        else:
+            icons = Image.open(f'{path}/icon/DENDRO_UP.png')
     elif x == "FIGHT_PROP_HEAL_ADD":
         icons = Image.open(f'{path}/icon/HEALED_ADD.png')
     elif x == "FIGHT_PROP_HEAL":
